# -------------------------------------------------------------------------
#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>

#     This program is free software; you can redistribute it and/or modify
#     it under the terms of the GNU General Public License as published by
#     the Free Software Foundation; either version 3 of the License, or
#     (at your option) any later version.

#     This program is distributed in the hope that it will be useful,
#     but WITHOUT ANY WARRANTY; without even the implied warranty of
#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#     GNU General Public License for more details.

#     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
#     main directory of the program
# -------------------------------------------------------------------------

# register basic objects
from stopper import *
from blocks import *
from objects import *

# register modules
from utilities import *
from processing import *
from mascot import *

# register parsers
from parser_xy import parseXY
from parser_mzxml import parseMZXML
from parser_mzdata import parseMZDATA
from parser_mzml import parseMZML
from parser_mgf import parseMGF
from parser_fasta import parseFASTA
